@@ -23,6 +23,10 @@
 #include "dwg.h"
 #include "bits.h"
 
+#ifdef IN_DXF_H
+#  error in_dxf.h must be included after print.h because of FORMAT_BD
+#endif
+
 int dwg_print_object (Bit_Chain *dat, Dwg_Object *obj);
 
 #endif
