@@ -7,7 +7,6 @@ api_process (dwg_object *obj)
   int error, isnew;
   BITCODE_BS i, num_entries;
   BITCODE_H *entries, *hdls;
-  BITCODE_BL objid;
 
   dwg_obj_appid_control *ctrl = dwg_object_to_APPID_CONTROL (obj);
 
@@ -20,14 +19,16 @@ api_process (dwg_object *obj)
       if (hdls[i] == entries[i])
         {
           if (entries[i])
-            ok ("APPID_CONTROL.entries[%d]: " FORMAT_REF, i, ARGS_REF (entries[i]));
+            ok ("APPID_CONTROL.entries[%d]: " FORMAT_REF, i,
+                ARGS_REF (entries[i]));
           else
             ok ("APPID_CONTROL.entries[%d]: NULL", i);
         }
       else
         {
           if (entries[i])
-            fail ("APPID_CONTROL.entries[%d]: " FORMAT_REF, i, ARGS_REF (entries[i]));
+            fail ("APPID_CONTROL.entries[%d]: " FORMAT_REF, i,
+                  ARGS_REF (entries[i]));
           else
             fail ("APPID_CONTROL.entries[%d]: NULL", i);
         }
