@@ -9,7 +9,8 @@ api_process (dwg_object *obj)
 
   Dwg_Version_Type dwg_version = obj->parent->header.version;
 #ifdef DEBUG_CLASSES
-  dwg_obj_blockpropertiestable *_obj = dwg_object_to_BLOCKPROPERTIESTABLE (obj);
+  dwg_obj_blockpropertiestable *_obj
+      = dwg_object_to_BLOCKPROPERTIESTABLE (obj);
 
 #endif
 }
