@@ -15,13 +15,16 @@ api_process (dwg_object *obj)
   BITCODE_BLx color_far;
 
   Dwg_Version_Type dwg_version = obj->parent->header.version;
-  dwg_obj_ground_plane_background *_obj = dwg_object_to_GROUND_PLANE_BACKGROUND (obj);
+  dwg_obj_ground_plane_background *_obj
+      = dwg_object_to_GROUND_PLANE_BACKGROUND (obj);
 
   CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, class_version, BL);
   CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_sky_zenith, BLx);
   CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_sky_horizon, BLx);
-  CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_underground_horizon, BLx);
-  CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_underground_azimuth, BLx);
+  CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_underground_horizon,
+                   BLx);
+  CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_underground_azimuth,
+                   BLx);
   CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_near, BLx);
   CHK_ENTITY_TYPE (_obj, GROUND_PLANE_BACKGROUND, color_far, BLx);
 }
